

/*	Copyright (C) 2005, 2006 by Andy Grebe a.k.a. tecknophreak(tecknophreak@gmail.com)
 *
 *	This file is part of TouchMe Games.
 *
 *	TouchMe Games is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	TouchMe Games is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with TouchMe Games; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <darttictactoe.h>
#include <algorithm>
#include <sstream>
#include <iomanip>
#include <termios.h>
#include <unistd.h>
#include <sys/time.h>

void DartTicTacToe::initScreen() {
	GtkWidget *eventBox;
	GtkWidget *label;
	GtkWidget *hbox, *vbox;
	std::stringstream sstr;
	GdkColor color;
	GtkRcStyle *rcstyle;
	
	scoreBg = gtk_rc_style_new();
	std::cout << "Score bg " << scoreBg << std::endl;
	color.red = 0x4600;
	color.green = 0x8200;
	color.blue = 0xB400;
		
	scoreBg->bg[0] = color;
	scoreBg->color_flags[0] = GTK_RC_BG;
	scoreBg->bg_pixmap_name[0] = "/usr/local/share/touchmegames/darttictactoe/images/smallscorebg.xpm";
	
	selectScoreBg = gtk_rc_style_new();
	std::cout << "Score bg " << selectScoreBg << std::endl;
	color.red = 0x4600;
	color.green = 0x8200;
	color.blue = 0xB400;
		
	selectScoreBg->bg[0] = color;
	selectScoreBg->color_flags[0] = GTK_RC_BG;
	selectScoreBg->bg_pixmap_name[0] = "/usr/local/share/touchmegames/darttictactoe/images/selectSmallscorebg.xpm";
	
	
	timeval tv;
	struct timezone tz;
	
	for (int i = 0; i < 9; ++i) {
		tttDoneLabels[i / 3][i % 3] = NULL;
	}
	
	tz.tz_minuteswest = 0;
	tz.tz_dsttime = 0;

	gettimeofday(&tv, &tz);
	srandom(tv.tv_usec);
	
	lhvbox = gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start((GtkBox *)tophbox, lhvbox, FALSE, FALSE, 0);
	
	midvbox = gtk_vbox_new(FALSE, 0);
	gtk_widget_set_size_request(midvbox, 400, -1);
	gtk_box_pack_start((GtkBox *)tophbox, midvbox, FALSE, FALSE, 0);
	
	rhvbox = gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start((GtkBox *)tophbox, rhvbox, FALSE, FALSE, 0);
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, 0, 30);
	gtk_box_pack_start((GtkBox *)lhvbox, label, FALSE, FALSE, 0);
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, 0, 30);
	gtk_box_pack_start((GtkBox *)rhvbox, label, FALSE, FALSE, 0);

	for (int i = 0; i < 2; ++i) {
		sstr.str("");
		sstr << "Player " << i + 1 ;//<< " - 0.00";
		playerLabels[i] = gtk_label_new(sstr.str().c_str());
		rcstyle = gtk_rc_style_new();//gtk_widget_get_modifier_style(label);
		rcstyle->font_desc = pango_font_description_new();
		pango_font_description_set_size(rcstyle->font_desc, 20 * PANGO_SCALE);
		pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
		color.red = 0xFFFF;
		color.green = 0xFFFF;
		color.blue = 0xFFFF;
		rcstyle->fg[0] = color;
		rcstyle->color_flags[0] = GTK_RC_FG;
		gtk_widget_modify_style(playerLabels[i], rcstyle);
		
		// Start of Player box
		playerEvent[i] = gtk_event_box_new();
		gtk_widget_set_size_request(playerEvent[i], 200, 100);
		if (i == 0) {
			gtk_widget_modify_style(playerEvent[0], selectScoreBg);
		}
		else {
			gtk_widget_modify_style(playerEvent[1], scoreBg);
		}
  pango_font_description_free(rcstyle->font_desc);
		
		//gtk_box_pack_start((GtkBox *)vbox, eventBox, FALSE, FALSE, 0);
		sstr.str("");
		sstr << (i ? 'O': 'X');
		playerScoreLabels[i] = gtk_label_new(sstr.str().c_str());
		rcstyle = gtk_rc_style_new();
		//rcstyle = gtk_widget_get_style(playerScoreLabels[i]);
		rcstyle->font_desc = pango_font_description_new();
		pango_font_description_set_size(rcstyle->font_desc, 60 * PANGO_SCALE);
		color.red = 0xFFFF;
		color.green = 0xFFFF;
		color.blue = 0xFFFF;
		rcstyle->fg[0] = color;
		rcstyle->color_flags[0] = GTK_RC_FG;
		pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
		gtk_widget_modify_style(playerScoreLabels[i], rcstyle);

		gtk_container_add((GtkContainer *)playerEvent[i], playerScoreLabels[i]);
		// end of player box
		
		if (i % 2) {
			gtk_box_pack_start((GtkBox *)rhvbox, playerLabels[i], FALSE, FALSE, 1);
			gtk_box_pack_start((GtkBox *)rhvbox, playerEvent[i], FALSE, FALSE, 0);
		}
		else {
			gtk_box_pack_start((GtkBox *)lhvbox, playerLabels[i], FALSE, FALSE, 1);
			gtk_box_pack_start((GtkBox *)lhvbox, playerEvent[i], FALSE, FALSE, 0);
		}
  pango_font_description_free(rcstyle->font_desc);
	}
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, -1, 20);
	gtk_box_pack_start((GtkBox *)midvbox, label, FALSE, FALSE, 0);
	
	playerLabel = gtk_label_new("Tic-Tac-Toe");
	rcstyle = gtk_rc_style_new();
	rcstyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(rcstyle->font_desc, 30 * PANGO_SCALE);
	pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	rcstyle->fg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_FG;
	gtk_widget_modify_style(playerLabel, rcstyle);
	gtk_box_pack_start((GtkBox *)midvbox, playerLabel, FALSE, FALSE, 0);
	
	label = gtk_label_new(" ");
	gtk_widget_set_size_request(label, -1, 5);
	gtk_box_pack_start((GtkBox *)midvbox, label, FALSE, FALSE, 0);
	
 
 
	hbox = gtk_hbox_new(FALSE, 0);
	gtk_widget_set_size_request(hbox, 400, 400);
	eventBox = gtk_event_box_new();
	gtk_widget_set_size_request(eventBox, 400, 400);
	rcstyle = gtk_rc_style_new();
	color.red = 0x4600;
	color.green = 0x8200;
	color.blue = 0xB400;
	rcstyle->bg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_BG;
	rcstyle->bg_pixmap_name[0] = "/usr/local/share/touchmegames/darttictactoe/images/tttbg.xpm";
	gtk_widget_modify_style(eventBox, rcstyle);
	
	ttttable = gtk_table_new(3, 3, TRUE);
	gtk_widget_set_size_request(ttttable, 400, 400);
	gtk_container_add((GtkContainer *)eventBox, ttttable);
 pango_font_description_free(rcstyle->font_desc);
	for (int i = 0; i < 9; ++i) {
		marks[i] = 0;
	}
	for (int x = 0; x < 3; ++x) {
		for (int y = 0; y < 3; ++y) {
			int tmp(0);
			while (!tmp) {
				tmp = random() % 20 + 1;
				for (int i = 0; i < 9; ++i) {
					if (marks[i] == tmp) {
						tmp = 0;
					}
				}
			}
			
			if (x == 1 && y == 1) {
				marks[4] = 25;
				
			}
			else {
				marks[x * 3 + y] = tmp;
				
			}
			std::cout << tmp << std::endl;
			tttvboxes[x][y] = gtk_vbox_new(FALSE, 0);
			tttlabels[x][y][0] = gtk_label_new(" ");
			rcstyle = gtk_rc_style_new();
			rcstyle->font_desc = pango_font_description_new();
			pango_font_description_set_size(rcstyle->font_desc, 16 * PANGO_SCALE);
			pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
//			color.red = 0xFFFF;
//			color.green = 0xFFFF;
//			color.blue = 0xFFFF;
//			rcstyle->fg[0] = color;
//			rcstyle->xthickness = 0;
//			rcstyle->color_flags[0] = GTK_RC_FG;
			gtk_widget_modify_style(tttlabels[x][y][0], rcstyle);
			gtk_box_pack_start((GtkBox *)tttvboxes[x][y], tttlabels[x][y][0], FALSE, FALSE, 0);
			sstr.str("");
			sstr << marks[x * 3 + y];
			label = gtk_label_new(sstr.str().c_str());
			rcstyle = gtk_rc_style_new();
			rcstyle->font_desc = pango_font_description_new();
			pango_font_description_set_size(rcstyle->font_desc, 50 * PANGO_SCALE);
			pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
   pango_font_description_free(rcstyle->font_desc);
   
//			color.red = 0xFFFF;
//			color.green = 0xFFFF;
//			color.blue = 0xFFFF;
//			rcstyle->fg[0] = color;
//			rcstyle->xthickness = 0;
//			rcstyle->color_flags[0] = GTK_RC_FG;
			gtk_widget_modify_style(label, rcstyle);
			gtk_box_pack_start((GtkBox *)tttvboxes[x][y], label, FALSE, FALSE, 0);
			tttlabels[x][y][1] = gtk_label_new(" ");
			rcstyle = gtk_rc_style_new();
			rcstyle->font_desc = pango_font_description_new();
			pango_font_description_set_size(rcstyle->font_desc, 16 * PANGO_SCALE);
			pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
//			color.red = 0xFFFF;
//			color.green = 0xFFFF;
//			color.blue = 0xFFFF;
//			rcstyle->fg[0] = color;
//			rcstyle->xthickness = 0;
//			rcstyle->color_flags[0] = GTK_RC_FG;
			gtk_widget_modify_style(tttlabels[x][y][1], rcstyle);
			gtk_box_pack_start((GtkBox *)tttvboxes[x][y], tttlabels[x][y][1], FALSE, FALSE, 0);
			gtk_table_attach_defaults((GtkTable *)ttttable, tttvboxes[x][y], x, x + 1, y, y + 1);
   pango_font_description_free(rcstyle->font_desc);
		}
	}
	gtk_box_pack_start((GtkBox *)hbox, eventBox, TRUE, FALSE, 0);
	gtk_box_pack_start((GtkBox *)midvbox, hbox, FALSE, FALSE, 0);
	
	
	
	
	round = 1;
	sstr.str("");
	sstr << "Round " << std::setw(3) << round;
	roundLabel = gtk_label_new(sstr.str().c_str());
	rcstyle = gtk_rc_style_new();
	rcstyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(rcstyle->font_desc, 30 * PANGO_SCALE);
	pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	rcstyle->fg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_FG;
	gtk_widget_modify_style(roundLabel, rcstyle);
	gtk_box_pack_start((GtkBox *)midvbox, roundLabel, FALSE, FALSE, 0);

 pango_font_description_free(rcstyle->font_desc);
	vbox = gtk_vbox_new(FALSE, 0);
	gtk_box_pack_end((GtkBox *)lhvbox, vbox, FALSE, FALSE, 0);
	
	for (int i = 0; i < 3; ++i) {
		
		dartImages[i] = gtk_image_new_from_file("/usr/local/share/touchmegames/dart01/images/dart.gif");
		gtk_box_pack_start((GtkBox *)vbox, dartImages[i], FALSE, FALSE, 2);
		dartLabels[i] = gtk_label_new("");
		rcstyle = gtk_rc_style_new();
		rcstyle->font_desc = pango_font_description_new();
		pango_font_description_set_size(rcstyle->font_desc, 23 * PANGO_SCALE);
		pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
		color.red = 0xFFFF;
		color.green = 0xFFFF;
		color.blue = 0xFFFF;
		rcstyle->fg[0] = color;
		rcstyle->color_flags[0] = GTK_RC_FG;
		gtk_widget_modify_style(dartLabels[i], rcstyle);
		gtk_box_pack_start((GtkBox *)vbox, dartLabels[i], FALSE, FALSE, 2);
  pango_font_description_free(rcstyle->font_desc);
	}
	
	gtk_widget_show_all(tophbox);
	
	for (int i = 0; i < 3; ++i) {
		gtk_widget_hide(dartLabels[i]);
	}
	
	openSerial();
	
	timer = gtk_timeout_add(100, timeout, this);
	currentPlayer = 0;
	currentDart = 0;
	currentScore = 0;
	
}

void DartTicTacToe::createMPRWindow() {
	GtkWidget *vbox;
	GdkColor color;
	GtkRcStyle *rcstyle;
	
	mprWindow = gtk_event_box_new();
	
	
	gtk_widget_set_size_request(mprWindow, 300, 150);
	rcstyle = gtk_rc_style_new();

	rcstyle->bg_pixmap_name[0] = "/usr/local/share/touchmegames/dart01/images/ppdbg.xpm";
	gtk_widget_modify_style(mprWindow, rcstyle);
	
	gtk_widget_modify_bg(mprWindow, GTK_STATE_NORMAL, &color);
	
	vbox = gtk_vbox_new(FALSE, 0);
	gtk_container_add((GtkContainer *)mprWindow, vbox);
	
	mprPlayerLabel = gtk_label_new("");
	rcstyle = gtk_rc_style_new();
	rcstyle->font_desc = pango_font_description_new();
	pango_font_description_set_size(rcstyle->font_desc, 40 * PANGO_SCALE);
	pango_font_description_set_weight(rcstyle->font_desc, PANGO_WEIGHT_BOLD);
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	rcstyle->fg[0] = color;
	rcstyle->color_flags[0] = GTK_RC_FG;
	
	gtk_widget_modify_style(mprPlayerLabel, rcstyle);
	mprLabel = gtk_label_new("");
	gtk_widget_modify_style(mprLabel, rcstyle);
	
	gtk_box_pack_start((GtkBox *)vbox, mprPlayerLabel, FALSE, FALSE, 5);
	gtk_box_pack_start((GtkBox *)vbox, mprLabel, FALSE, FALSE, 5);
	
	gtk_fixed_put(GTK_FIXED(fixed), mprWindow, 250, 300);
 pango_font_description_free(rcstyle->font_desc);
}

void DartTicTacToe::createGameOver1() {
	GtkWidget *label;
	GtkWidget *vbox;
	GtkWidget *button;
	GtkWidget *eventBox;
	GdkColor color;
	GtkStyle *style;
	int lh(1), rh(2);
	int round;
	
	std::cout << "Winner " << winner << std::endl;
	
	round = atoi(gtk_label_get_text((GtkLabel *)roundLabel));
	for (int i = 0; i < 2; ++i) {
		finalScore[i] = atoi(gtk_label_get_text((GtkLabel *)playerScoreLabels[i]));
	}
	
	gtk_widget_destroy(lhvbox);
	gtk_widget_destroy(rhvbox);
	gtk_widget_destroy(midvbox);
	
	vbox = gtk_vbox_new(FALSE, 0);
	table = gtk_table_new(7, 9, TRUE);
	gtk_box_pack_start((GtkBox *)vbox, table, FALSE, FALSE, 0);
	gtk_table_set_row_spacings((GtkTable *)table, 3);
	gtk_table_set_col_spacings((GtkTable *)table, 3);
	
	color.red = 0xFFFF;
	color.green = 0xFFFF;
	color.blue = 0xFFFF;
	
	label = gtk_label_new("Winner");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	style = gtk_widget_get_style(label);
	style->fg[0] = color;
	pango_font_description_set_size(style->font_desc, 14 * PANGO_SCALE);
	pango_font_description_set_weight(style->font_desc, PANGO_WEIGHT_BOLD);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("Score");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach(GTK_TABLE (table), label, 0, 1, 2, 3,
			 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("Darts");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	style = gtk_widget_get_style(label);
	style->fg[0] = color;
	pango_font_description_set_size(style->font_desc, 14 * PANGO_SCALE);
	pango_font_description_set_weight(style->font_desc, PANGO_WEIGHT_BOLD);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("Doubles");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("Triples");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("MPD");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 6, 7,
			  (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	label = gtk_label_new("MPR");
	gtk_misc_set_alignment((GtkMisc *)label, 0, 0.5);
	gtk_widget_set_style(label, style);
	gtk_table_attach(GTK_TABLE (table), label, 0, 1, 7, 8,
			 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
			  (GtkAttachOptions)(0), 0, 0);
	
	
	for (int i = 0; i < 2; ++i) {
		std::stringstream sstr;
		// Label
		sstr << "Player " << i + 1;
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 0, 1,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << (winner == i ? 1: 0);
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 1, 2,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
				 
		sstr.str("");
		sstr << (float)finalScore[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 2, 3,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << darts[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 3, 4,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << doubles[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 4, 5,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << triples[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 5, 6,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << std::setprecision(3) << (float)playerMarks[i] / (float)darts[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 6, 7,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		sstr.str("");
		sstr << std::setprecision(4) << (float)playerMarks[i] / (float)rounds[i];
		label = gtk_label_new(sstr.str().c_str());
		gtk_misc_set_alignment((GtkMisc *)label, 1, 0.5);
		gtk_widget_set_style(label, style);
		gtk_table_attach(GTK_TABLE (table), label, lh, rh, 7, 8,
				 (GtkAttachOptions)(GTK_FILL | GTK_EXPAND),
				 (GtkAttachOptions)(0), 0, 0);
		
		++rh;
		++lh;
	}
	eventBox = gtk_event_box_new();
	button = gtk_image_new_from_file("/usr/local/share/touchmegames/dart01/images/exitgame.gif");
	gtk_event_box_set_visible_window((GtkEventBox *)eventBox, FALSE);
	gtk_widget_add_events(eventBox, GDK_BUTTON_PRESS_MASK);
	g_signal_connect(G_OBJECT(eventBox), 
			 "button-press-event",
			 G_CALLBACK(exitGame), (gpointer)this);
	
	gtk_container_add((GtkContainer *)eventBox, button);
	gtk_box_pack_start((GtkBox *)vbox, eventBox, FALSE, FALSE, 50);
	gtk_box_pack_start((GtkBox *)tophbox, vbox, FALSE, FALSE, 0);
	gtk_widget_show_all(vbox);
}

GtkWidget *DartTicTacToe::init() {
	GAME_PTR::loadScores(scores);
	fixed = gtk_fixed_new();
	gtk_widget_ref(fixed);
	
	for (int x = 0; x < 3; ++x) {
		for (int y = 0; y < 3; ++y) {
			tttDoneLabels[x][y] = NULL;
		}
	}
	
	// init all to 0
	for (int i = 0; i < 2; ++i) {
		darts[i] = 0;
		finalScore[i] = 0;
		rounds[i] = 0;
		doubles[i] = 0;
		triples[i] = 0;
		playerMarks[i] = 0;
	}
	winner = -1;
	
	tophbox = gtk_hbox_new(FALSE, 0);
	
	createMPRWindow();
	
	initScreen();
	//gtk_box_pack_start((GtkBox *)tophbox, , TRUE, FALSE, 5);
	
	gtk_fixed_put(GTK_FIXED(fixed), tophbox, 0, 0);
	gtk_widget_show(fixed);
	gtk_widget_hide_all(mprWindow);
	return fixed;
	//return label;
}

void DartTicTacToe::openSerial() {
	if (!dartBoard.init("/dev/ttyS0")) {
		std::cout << "No init" << std::endl;
	}
	dartBoard.setDoubleBull(true);
	if (!dartBoard.dartBoardPresent()) {
		// we gots ourselves some trouble.
	}
}
